# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class IntegrationExportCreateDto(BaseModel):
    """
    IntegrationExportCreateDto
    """ # noqa: E501
    disable_launch_sync: Optional[StrictBool] = Field(default=None, alias="disableLaunchSync")
    disable_tc_create: Optional[StrictBool] = Field(default=None, alias="disableTcCreate")
    disabled: Optional[StrictBool] = None
    integration_id: StrictInt = Field(alias="integrationId")
    launch_aql: Optional[StrictStr] = Field(default=None, alias="launchAql")
    notification_email: Optional[StrictStr] = Field(default=None, alias="notificationEmail")
    project_id: StrictInt = Field(alias="projectId")
    project_key: Optional[StrictStr] = Field(default=None, alias="projectKey")
    settings: Optional[Any] = None
    sync_delay_sec: Optional[StrictInt] = Field(default=None, alias="syncDelaySec")
    tc_aql: Optional[StrictStr] = Field(default=None, alias="tcAql")
    __properties: ClassVar[List[str]] = ["disableLaunchSync", "disableTcCreate", "disabled", "integrationId", "launchAql", "notificationEmail", "projectId", "projectKey", "settings", "syncDelaySec", "tcAql"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IntegrationExportCreateDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if settings (nullable) is None
        # and model_fields_set contains the field
        if self.settings is None and "settings" in self.model_fields_set:
            _dict['settings'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IntegrationExportCreateDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "disableLaunchSync": obj.get("disableLaunchSync"),
            "disableTcCreate": obj.get("disableTcCreate"),
            "disabled": obj.get("disabled"),
            "integrationId": obj.get("integrationId"),
            "launchAql": obj.get("launchAql"),
            "notificationEmail": obj.get("notificationEmail"),
            "projectId": obj.get("projectId"),
            "projectKey": obj.get("projectKey"),
            "settings": obj.get("settings"),
            "syncDelaySec": obj.get("syncDelaySec"),
            "tcAql": obj.get("tcAql")
        })
        return _obj


