# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class IntegrationOperationTypeDto(str, Enum):
    """
    IntegrationOperationTypeDto
    """

    """
    allowed enum values
    """
    ISSUE_CREATE = 'issue_create'
    ISSUE_EXPORT_LAUNCH = 'issue_export_launch'
    ISSUE_SUGGEST = 'issue_suggest'
    ISSUE_SYNC = 'issue_sync'
    JOB_RUN = 'job_run'
    JOB_SUGGEST = 'job_suggest'
    JOB_SYNC = 'job_sync'
    TMS_SYNC = 'tms_sync'
    TEST_KEY_SUGGEST = 'test_key_suggest'
    TEST_KEY_SYNC = 'test_key_sync'
    AI_CHAT = 'ai_chat'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of IntegrationOperationTypeDto from a JSON string"""
        return cls(json.loads(json_str))


