# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from src.client.generated.models.test_case_attachment_row_dto import TestCaseAttachmentRowDto
from typing import Optional, Set
from typing_extensions import Self

class TestCaseScenarioStepDto(BaseModel):
    """
    TestCaseScenarioStepDto
    """ # noqa: E501
    attachments: Optional[List[TestCaseAttachmentRowDto]] = None
    expected_result: Optional[StrictStr] = Field(default=None, alias="expectedResult")
    has_content: Optional[StrictBool] = Field(default=None, alias="hasContent")
    keyword: Optional[StrictStr] = None
    leaf: Optional[StrictBool] = None
    name: Optional[StrictStr] = None
    steps: Optional[List[TestCaseScenarioStepDto]] = None
    steps_count: Optional[StrictInt] = Field(default=None, alias="stepsCount")
    __properties: ClassVar[List[str]] = ["attachments", "expectedResult", "hasContent", "keyword", "leaf", "name", "steps", "stepsCount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TestCaseScenarioStepDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "has_content",
            "leaf",
            "steps_count",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in steps (list)
        _items = []
        if self.steps:
            for _item_steps in self.steps:
                if _item_steps:
                    _items.append(_item_steps.to_dict())
            _dict['steps'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TestCaseScenarioStepDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "attachments": [TestCaseAttachmentRowDto.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "expectedResult": obj.get("expectedResult"),
            "hasContent": obj.get("hasContent"),
            "keyword": obj.get("keyword"),
            "leaf": obj.get("leaf"),
            "name": obj.get("name"),
            "steps": [TestCaseScenarioStepDto.from_dict(_item) for _item in obj["steps"]] if obj.get("steps") is not None else None,
            "stepsCount": obj.get("stepsCount")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
TestCaseScenarioStepDto.model_rebuild(raise_errors=False)

