# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from src.client.generated.models.test_fixture_result_type_dto import TestFixtureResultTypeDto
from src.client.generated.models.test_result_scenario_v2_dto import TestResultScenarioV2Dto
from src.client.generated.models.test_status import TestStatus
from typing import Optional, Set
from typing_extensions import Self

class TestFixtureResultV2Dto(BaseModel):
    """
    TestFixtureResultV2Dto
    """ # noqa: E501
    duration: Optional[StrictInt] = None
    id: Optional[StrictInt] = None
    message: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    scenario: Optional[TestResultScenarioV2Dto] = None
    start: Optional[StrictInt] = None
    status: Optional[TestStatus] = None
    stop: Optional[StrictInt] = None
    trace: Optional[StrictStr] = None
    type: Optional[TestFixtureResultTypeDto] = None
    __properties: ClassVar[List[str]] = ["duration", "id", "message", "name", "scenario", "start", "status", "stop", "trace", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TestFixtureResultV2Dto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of scenario
        if self.scenario:
            _dict['scenario'] = self.scenario.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TestFixtureResultV2Dto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "duration": obj.get("duration"),
            "id": obj.get("id"),
            "message": obj.get("message"),
            "name": obj.get("name"),
            "scenario": TestResultScenarioV2Dto.from_dict(obj["scenario"]) if obj.get("scenario") is not None else None,
            "start": obj.get("start"),
            "status": obj.get("status"),
            "stop": obj.get("stop"),
            "trace": obj.get("trace"),
            "type": obj.get("type")
        })
        return _obj


