# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class IntegrationTypeDto(str, Enum):
    """
    IntegrationTypeDto
    """

    """
    allowed enum values
    """
    ALLURE_TESTOPS = 'allure_testops'
    AZURE = 'azure'
    BAMBOO = 'bamboo'
    BITBUCKET = 'bitbucket'
    CIRCLECI = 'circleci'
    GITHUB = 'github'
    GITLAB = 'gitlab'
    JENKINS = 'jenkins'
    JIRA = 'jira'
    JIRA_CLOUD = 'jira_cloud'
    REDMINE = 'redmine'
    TARGET_PROCESS = 'target_process'
    TEAMCITY = 'teamcity'
    TEKTON = 'tekton'
    TESTRAIL = 'testrail'
    XRAY = 'xray'
    XRAY_CLOUD = 'xray_cloud'
    YOUTRACK = 'youtrack'
    ZEPHYR_SCALE = 'zephyr_scale'
    ZEPHYR_SCALE_CLOUD = 'zephyr_scale_cloud'
    YANDEX_TRACKER = 'yandex_tracker'
    CUSTOM = 'custom'
    AWS = 'aws'
    WRIKE = 'wrike'
    KAITEN = 'kaiten'
    CHAT_GPT = 'chat_gpt'
    DEEP_SEEK = 'deep_seek'
    MISTRAL_AI = 'mistral_ai'
    OLLAMA = 'ollama'
    YANDEX_GPT = 'yandex_gpt'
    GIGA_CHAT = 'giga_chat'
    BITRIX24 = 'bitrix24'
    CLICKUP = 'clickup'
    EVA_PROJECT = 'eva_project'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of IntegrationTypeDto from a JSON string"""
        return cls(json.loads(json_str))


