# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TestResultExportField(str, Enum):
    """
    TestResultExportField
    """

    """
    allowed enum values
    """
    ALLURE_ID = 'allure_id'
    NAME = 'name'
    FULL_NAME = 'full_name'
    DESCRIPTION = 'description'
    STATUS = 'status'
    START = 'start'
    STOP = 'stop'
    DURATION = 'duration'
    PRECONDITION = 'precondition'
    EXPECTED_RESULT = 'expected_result'
    MESSAGE = 'message'
    TEST_CASE_ID = 'test_case_id'
    TEST_CASE_STATUS = 'test_case_status'
    LAYER = 'layer'
    ISSUE_INTEGRATION = 'issue_integration'
    SCENARIO = 'scenario'
    ROLE = 'role'
    CUSTOM_FIELD = 'custom_field'
    TAG = 'tag'
    LINK = 'link'
    PARAMETER = 'parameter'
    EXECUTOR = 'executor'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TestResultExportField from a JSON string"""
        return cls(json.loads(json_str))


