# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TestCaseExportField(str, Enum):
    """
    TestCaseExportField
    """

    """
    allowed enum values
    """
    ALLURE_ID = 'allure_id'
    NAME = 'name'
    FULL_NAME = 'full_name'
    AUTOMATED = 'automated'
    DESCRIPTION = 'description'
    PRECONDITION = 'precondition'
    EXPECTED_RESULT = 'expected_result'
    STATUS = 'status'
    SCENARIO = 'scenario'
    ISSUE_INTEGRATION = 'issue_integration'
    TAG = 'tag'
    LINK = 'link'
    CUSTOM_FIELD = 'custom_field'
    ROLE = 'role'
    EXAMPLE = 'example'
    PARAMETER = 'parameter'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TestCaseExportField from a JSON string"""
        return cls(json.loads(json_str))


