# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TestCaseBulkCfMoveStrategy(str, Enum):
    """
    TestCaseBulkCfMoveStrategy
    """

    """
    allowed enum values
    """
    ADD = 'ADD'
    MAP = 'MAP'
    EXCLUDE = 'EXCLUDE'
    REWRITE = 'REWRITE'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TestCaseBulkCfMoveStrategy from a JSON string"""
        return cls(json.loads(json_str))


