# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from src.client.generated.models.job_info_dto import JobInfoDto
from src.client.generated.models.job_run_stage_dto import JobRunStageDto
from src.client.generated.models.job_run_status_dto import JobRunStatusDto
from typing import Optional, Set
from typing_extensions import Self

class JobRunDto(BaseModel):
    """
    JobRunDto
    """ # noqa: E501
    created_by: Optional[StrictStr] = Field(default=None, alias="createdBy")
    created_date: Optional[StrictInt] = Field(default=None, alias="createdDate")
    error_message: Optional[StrictStr] = Field(default=None, alias="errorMessage")
    external_id: Optional[StrictStr] = Field(default=None, alias="externalId")
    id: Optional[StrictInt] = None
    job: Optional[JobInfoDto] = None
    last_modified_by: Optional[StrictStr] = Field(default=None, alias="lastModifiedBy")
    last_modified_date: Optional[StrictInt] = Field(default=None, alias="lastModifiedDate")
    launch_id: Optional[StrictInt] = Field(default=None, alias="launchId")
    name: Optional[StrictStr] = None
    stage: Optional[JobRunStageDto] = None
    status: Optional[JobRunStatusDto] = None
    url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["createdBy", "createdDate", "errorMessage", "externalId", "id", "job", "lastModifiedBy", "lastModifiedDate", "launchId", "name", "stage", "status", "url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of JobRunDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of job
        if self.job:
            _dict['job'] = self.job.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of JobRunDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "createdBy": obj.get("createdBy"),
            "createdDate": obj.get("createdDate"),
            "errorMessage": obj.get("errorMessage"),
            "externalId": obj.get("externalId"),
            "id": obj.get("id"),
            "job": JobInfoDto.from_dict(obj["job"]) if obj.get("job") is not None else None,
            "lastModifiedBy": obj.get("lastModifiedBy"),
            "lastModifiedDate": obj.get("lastModifiedDate"),
            "launchId": obj.get("launchId"),
            "name": obj.get("name"),
            "stage": obj.get("stage"),
            "status": obj.get("status"),
            "url": obj.get("url")
        })
        return _obj


