# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from src.client.generated.models.page_access_group_dto_sort import PageAccessGroupDtoSort
from src.client.generated.models.pageable import Pageable
from src.client.generated.models.shared_step_dto import SharedStepDto
from typing import Optional, Set
from typing_extensions import Self

class PageSharedStepDto(BaseModel):
    """
    PageSharedStepDto
    """ # noqa: E501
    content: Optional[List[SharedStepDto]] = None
    empty: Optional[StrictBool] = None
    first: Optional[StrictBool] = None
    last: Optional[StrictBool] = None
    number: Optional[StrictInt] = None
    number_of_elements: Optional[StrictInt] = Field(default=None, alias="numberOfElements")
    pageable: Optional[Pageable] = None
    size: Optional[StrictInt] = None
    sort: Optional[PageAccessGroupDtoSort] = None
    total_elements: Optional[StrictInt] = Field(default=None, alias="totalElements")
    total_pages: Optional[StrictInt] = Field(default=None, alias="totalPages")
    __properties: ClassVar[List[str]] = ["content", "empty", "first", "last", "number", "numberOfElements", "pageable", "size", "sort", "totalElements", "totalPages"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PageSharedStepDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in content (list)
        _items = []
        if self.content:
            for _item_content in self.content:
                if _item_content:
                    _items.append(_item_content.to_dict())
            _dict['content'] = _items
        # override the default output from pydantic by calling `to_dict()` of pageable
        if self.pageable:
            _dict['pageable'] = self.pageable.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sort
        if self.sort:
            _dict['sort'] = self.sort.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PageSharedStepDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "content": [SharedStepDto.from_dict(_item) for _item in obj["content"]] if obj.get("content") is not None else None,
            "empty": obj.get("empty"),
            "first": obj.get("first"),
            "last": obj.get("last"),
            "number": obj.get("number"),
            "numberOfElements": obj.get("numberOfElements"),
            "pageable": Pageable.from_dict(obj["pageable"]) if obj.get("pageable") is not None else None,
            "size": obj.get("size"),
            "sort": PageAccessGroupDtoSort.from_dict(obj["sort"]) if obj.get("sort") is not None else None,
            "totalElements": obj.get("totalElements"),
            "totalPages": obj.get("totalPages")
        })
        return _obj


