# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class WidgetTypeDto(str, Enum):
    """
    WidgetTypeDto
    """

    """
    allowed enum values
    """
    MARKDOWN = 'markdown'
    ANALYTICS_GRAPH = 'analytics_graph'
    TC_PIE_CHART = 'tc_pie_chart'
    AUTOMATION_TREND = 'automation_trend'
    AUTOMATION_TREND_V2 = 'automation_trend_v2'
    STATISTIC_TREND = 'statistic_trend'
    TOP_TC = 'top_tc'
    TC_TREE_MAP = 'tc_tree_map'
    LAUNCH_LIST = 'launch_list'
    LAST_LAUNCH_PIE_CHART = 'last_launch_pie_chart'
    LAUNCH_TREND = 'launch_trend'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WidgetTypeDto from a JSON string"""
        return cls(json.loads(json_str))


